@@ -1,5 +1,5 @@
-from .dependencies import json_fix
-from .dependencies import file_system_py as FS
+from .__dependencies__ import json_fix
+from .__dependencies__ import file_system_py as FS
 
 from time import time as now
 from random import shuffle
@@ -29,6 +29,19 @@ if True:
 # data structures
 # 
 if True:
+    def singleton(a_class):
+        """
+        @singleton
+        SomeClass:
+            thing = 10
+            @property
+            def double_thing(self):
+                return self.thing * 2
+        
+        print(SomeClass.double_thing) # >>> 20
+        """
+        return a_class()
+    
     class Object: # just an empty object for assigning attributes of
         def __init__(self, **kwargs):
             for each_key, each_value in kwargs.items():
@@ -329,7 +342,6 @@ if True:
             return debug_string
     stringify.onelineify_threshold = 50
     
-    
     def is_required_by(*args, **kwargs):
         """
             Summary:
@@ -347,6 +359,26 @@ if True:
         """
         def decorator(function_being_wrapped):
             return function_being_wrapped
+        return decorator
+    
+    def is_used_by(*args, **kwargs):
+        """
+            Summary:
+                A way to know why a method function exists, and know if it can be renamed
+                (A way of mapping out dependencies)
+            
+            Example:
+                import custom_json_thing
+                
+                class Thing:
+                    @is_used_by(custom_json_thing)
+                    def to_json(self):
+                        return "something"
+                        
+        """
+        def decorator(function_being_wrapped):
+            return function_being_wrapped
+        return decorator
 
 #
 # iterative helpers
